Learn R Programming

ThreeWiseMonkeys (version 0.1.0)

Speak: speak no evil

Description

Plays an audioclip of the words "No evil". On Windows and Linux machines the function should directly call the system default player of .wav files. On Mac machines it might be necessary to set the default with something like tuneR::setWavPlayer("/Applications/'QuickTime Player.app'/Contents/MacOS/'QuickTime Player'").

Usage

Speak(...)

Arguments

...

an input, doesn't matter, isn't used

Value

Plays an audio clip of the words "No Evil.".

Examples

Run this code
# NOT RUN {
Speak()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab