Plays an audioclip of the words "No evil".
On Windows and Linux machines the function should directly call the system default player of .wav files.
On Mac machines it might be necessary to set the default with something like tuneR::setWavPlayer("/Applications/'QuickTime Player.app'/Contents/MacOS/'QuickTime Player'").